|PyPI Version| |Build Status| |Coverage Status| |Python Version| |Pypi Downloads|

Scrapyd is a service for deploying and running `Scrapy <https://scrapy.org>`__ spiders.

It allows you to upload Scrapy projects and control their spiders using a JSON API.

(If you are viewing this on GitHub, open the `full documentation <https://scrapyd.readthedocs.io/>`__ for additional details.)

.. |PyPI Version| image:: https://img.shields.io/pypi/v/scrapyd.svg
   :target: https://pypi.org/project/scrapyd/
.. |Build Status| image:: https://github.com/scrapy/scrapyd/workflows/Tests/badge.svg
.. |Coverage Status| image:: https://coveralls.io/repos/github/scrapy/scrapyd/badge.svg?branch=master
   :target: https://coveralls.io/github/scrapy/scrapyd?branch=master
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/scrapyd.svg
   :target: https://pypi.org/project/scrapyd/
.. |Pypi Downloads| image:: https://img.shields.io/pypi/dm/scrapyd.svg
   :target: https://pypi.python.org/pypi/scrapyd/
